import type { DefaultTheme } from "./theme-provider";
import { Maybe } from "./typeUtils";
type LowercaseCharacter = "a" | "b" | "c" | "d" | "e" | "f" | "g" | "h" | "i" | "j" | "k" | "l" | "m" | "n" | "o" | "p" | "q" | "r" | "s" | "t" | "u" | "v" | "w" | "x" | "y" | "z";
type AllCharacter = LowercaseCharacter | Uppercase<LowercaseCharacter>;
type NonEmptyString = `${AllCharacter}${string}`;
type CSSLengthUnit = `${number}${LengthUnit}`;
type CSSCustomProperties = `--${NonEmptyString}`;
type CSSCustomPropertiesWithVar = `var(${CSSCustomProperties})`;
type LengthUnit = "vmin" | "vmax" | "vh" | "vw" | "%" | "ch" | "ex" | "em" | "rem" | "in" | "cm" | "mm" | "pt" | "pc" | "px";
export type CSSLength = CSSLengthUnit | CSSCustomPropertiesWithVar | CSSCustomProperties;
export declare function checkIsCSSLength(str: string): str is CSSLength;
declare const space: {
    size000: string;
    size00: string;
    size1: string;
    size2: string;
    size3: string;
    size4: string;
    size5: string;
    size6: string;
    size7: string;
    size8: string;
    size9: string;
    size10: string;
    size11: string;
    size12: string;
    size13: string;
    size14: string;
    size15: string;
};
declare const size: {
    sizeXxs: string;
    sizeXs: string;
    sizeSm: string;
    sizeMd: string;
    sizeLg: string;
    sizeXl: string;
    sizeXxl: string;
    sizeContent1: string;
    sizeContent2: string;
    sizeContent3: string;
    sizeHeader1: string;
    sizeHeader2: string;
    sizeHeader3: string;
};
export declare const spacing: Record<keyof typeof space, CSSLength>;
export declare const sizes: Record<keyof typeof size, CSSLength>;
export type BaseTheme = Record<string, CSSLength | string | number>;
type ThemeOrDefaultSpace<T> = T extends {
    space: BaseTheme;
} ? keyof T["space"] : keyof typeof spacing;
export type SpacingOptions = ThemeOrDefaultSpace<DefaultTheme>;
export type SizesOptions = ThemeOrDefaultSizes<DefaultTheme>;
type ThemeOrDefaultSizes<T> = T extends {
    sizes: BaseTheme;
} ? T["sizes"] : keyof typeof sizes;
export type Gutter = CSSLength | number | SpacingOptions;
export declare function getSafeGutter<T extends DefaultTheme>(theme: T, gutter?: Gutter): Maybe<CSSLength>;
export declare function getSpacingValue<T extends DefaultTheme>(theme: Readonly<T & {
    space?: BaseTheme;
}>, spacingKey: SpacingOptions): Maybe<CSSLength>;
export declare function getSizeValue<T extends DefaultTheme>(theme: Readonly<T & {
    sizes?: BaseTheme;
}>, sizeKey?: CSSLength | number | SizesOptions | "fit-content" | "max-content" | "min-content" | "auto"): Maybe<CSSLength>;
export {};
